.. _github-stats-3-6-3:

GitHub statistics for 3.6.3 (Jan 11, 2023)
==========================================

GitHub statistics for 2022/11/02 (tag: v3.6.2) - 2023/01/11

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 16 issues and merged 107 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/76?closed=1>`__

The following 20 authors contributed 198 commits.

* Antony Lee
* Chahak Mehta
* David Stansby
* Elliott Sales de Andrade
* Eric Larson
* hannah
* iofall
* Jody Klymak
* Kaidong Hu
* Kyle Sunden
* matt statham
* Matthias Bussonnier
* Muhammad Abdur Rakib
* Oscar Gustafsson
* ramvikrams
* Ruth Comer
* Steffen Rehberg
* Thomas A Caswell
* Tim Hoffmann
* yuanx749

GitHub issues and pull requests:

Pull Requests (107):

* :ghpull:`24939`: Backport PR #23390 on branch v3.6.x (FIX: colorbar contour with log norm should default to log locator and formatter...)
* :ghpull:`24936`: Backport PR #24927 on branch v3.6.x (DOC: Remove space after directive name, before double-colon)
* :ghpull:`23390`: FIX: colorbar contour with log norm should default to log locator and formatter...
* :ghpull:`24932`: Backport PR #24783 on branch v3.6.x (inset locator fix with tests added)
* :ghpull:`24783`: inset locator fix with tests added
* :ghpull:`24927`: DOC: Remove space after directive name, before double-colon
* :ghpull:`24881`: Backport PR #24880 on branch v3.6.x (Minor cleanups to named colors example.)
* :ghpull:`24876`: Backport PR #24873 on branch v3.6.x (Copy-edit fonts docs.)
* :ghpull:`24857`: Backport PR #24856 on branch v3.6.x (fix typo)
* :ghpull:`24852`: Backport PR #24843 on branch v3.6.x (Show that fill_between and span_where provide similar functionalities.)
* :ghpull:`24808`: Backport PR #24807 on branch v3.6.x (Axes.stem docstring document orientation as literals)
* :ghpull:`24807`: Axes.stem docstring document orientation as literals
* :ghpull:`24791`: Backport PR #24785 on branch v3.6.x (Fix random generation of single floats)
* :ghpull:`24777`: Backport PR #24772 on branch v3.6.x (Fix Left ventricle bullseye example)
* :ghpull:`24775`: Backport PR #24774 on branch v3.6.x (DOC: fix strip_chart example with numpy 1.24)
* :ghpull:`24765`: Backport PR #24764 on branch v3.6.x (DOC: ``subplot_mosaic`` tutorial - clarify ratios keywords used directly)
* :ghpull:`24739`: Backport PR #24732 on branch v3.6.x (Use masked stack to preserve mask info)
* :ghpull:`24738`: Backport PR #24735 on branch v3.6.x (Correct note about aspect)
* :ghpull:`24732`: Use masked stack to preserve mask info
* :ghpull:`24735`: Correct note about aspect
* :ghpull:`24729`: Backport PR #24715 on branch v3.6.x (Add note that users do not instantiate Axes directly)
* :ghpull:`24715`: Add note that users do not instantiate Axes directly
* :ghpull:`24721`: Backport PR #24607 on branch v3.6.x (DOC: tweak wording on Figure.show warning)
* :ghpull:`24607`: DOC: tweak wording on Figure.show warning
* :ghpull:`24694`: Backport PR #24692 on branch v3.6.x (Avoid rgba8888->argb32 conversion if qt can do it for us.)
* :ghpull:`24692`: Avoid rgba8888->argb32 conversion if qt can do it for us.
* :ghpull:`24684`: Backport PR #24654: Don't manually invalidate cached lines in _update_transScale
* :ghpull:`24687`: Backport PR #24003 on branch v3.6.x (Fix wording and links lifecycle tutorial)
* :ghpull:`24685`: Backport PR #23974 on branch v3.6.x (Fix repeated word typos)
* :ghpull:`24680`: Backport PR #24677 on branch v3.6.x (FIX: do not replace the Axes._children list object)
* :ghpull:`24677`: FIX: do not replace the Axes._children list object
* :ghpull:`24659`: Backport PR #24657 on branch v3.6.x (BUG: Fix bug with mutable input modification)
* :ghpull:`24657`: BUG: Fix bug with mutable input modification
* :ghpull:`24654`: Don't manually invalidate cached lines in _update_transScale.
* :ghpull:`24650`: Backport PR #24645 on branch v3.6.x (Removed 'above' wording from Input hook integration docs (#24632))
* :ghpull:`24647`: Backport PR #24643 on branch v3.6.x (DOC: annotation coords are not floats)
* :ghpull:`24643`: DOC: annotation coords are not floats
* :ghpull:`24625`: Backport PR #24606: FIX: do not use deprecated API in gtk4 backend
* :ghpull:`24633`: Backport PR #24592 on branch v3.6.x (DOC: Don't try to link paths that are on a different drive)
* :ghpull:`24592`: DOC: Don't try to link paths that are on a different drive
* :ghpull:`24628`: Backport PR #24584 on branch v3.6.x (DOC: add "See Also: draw_idle" reference to pyplot.draw)
* :ghpull:`24584`: DOC: add "See Also: draw_idle" reference to pyplot.draw
* :ghpull:`24601`: Backport PR #24600 on branch v3.6.x (Fix: Gracefully fail the string validator for tuple inputs)
* :ghpull:`24609`: Backport PR #24595 on branch v3.6.x (ci: Stop building wheels on AppVeyor)
* :ghpull:`24616`: Backport PR #24397 on branch v3.6.x (Simplify appveyor to only use conda)
* :ghpull:`24615`: Backport PR #24598 on branch v3.6.x (Check for errors/warnings on failed doc-builds)
* :ghpull:`24606`: FIX: do not use deprecated API in gtk4 backend
* :ghpull:`24612`: Backport PR #23868 on branch v3.6.x (Show errors and warnings in doc CI after build.)
* :ghpull:`24595`: ci: Stop building wheels on AppVeyor
* :ghpull:`24600`: Fix: Gracefully fail the string validator for tuple inputs
* :ghpull:`24593`: Backport PR #24580 on branch v3.6.x (Update the polar transform information in doc #24499)
* :ghpull:`24587`: Backport PR #24579: Add explicit permissions to GitHub Actions
* :ghpull:`24579`: Add explicit permissions to GitHub Actions
* :ghpull:`24561`: Backport PR #24540 on branch v3.6.x (DOC: add note about enabling c++11 support for old gcc)
* :ghpull:`24559`: Backport PR #24299 on branch v3.6.x (Rework style sheet reference example to cycle props)
* :ghpull:`24551`: Backport PR #24548 on branch v3.6.x (DOC: improved the doc for layout_engine.py)
* :ghpull:`24548`: DOC: improved the doc for layout_engine.py
* :ghpull:`24535`: Backport PR #24514 on branch v3.6.x (Fix potential issue in contour)
* :ghpull:`24534`: Backport PR #24521 on branch v3.6.x (Doc: improve spelling and grammar)
* :ghpull:`24533`: Backport PR #24517 on branch v3.6.x (DOC: improve grammar and consistency)
* :ghpull:`24532`: Backport PR #24520 on branch v3.6.x (Doc: Fix grammar and spelling)
* :ghpull:`24514`: Fix potential issue in contour
* :ghpull:`24521`: Doc: improve spelling and grammar
* :ghpull:`24517`: DOC: improve grammar and consistency
* :ghpull:`24520`: Doc: Fix grammar and spelling
* :ghpull:`24515`: Backport PR #24512 on branch v3.6.x (Tweak markup in toolkits tutorials.)
* :ghpull:`24503`: Backport PR #24502 on branch v3.6.x (Remove link from demo_floating_axes title.)
* :ghpull:`24505`: Backport PR #24482 on branch v3.6.x (Use relative frame path in HTMLWriter)
* :ghpull:`24506`: Backport of PR#24488 (Update for pydata-sphinx-theme 0.12.0)
* :ghpull:`24482`: Use relative frame path in HTMLWriter
* :ghpull:`24496`: Backport PR #24495 on branch v3.6.x (Update adding of google analytics key for docs)
* :ghpull:`24495`: Update adding of google analytics key for docs
* :ghpull:`24488`: Update for pydata-sphinx-theme 0.12.0
* :ghpull:`24485`: Backport PR #24481 on branch v3.6.x (Fix floating-point drift in oscilloscope example)
* :ghpull:`24475`: DOC: Fix examples gallery layout issues
* :ghpull:`24478`: Backport PR #24444 on branch v3.6.x (DOC: AnnotationBbox keyword descriptions)
* :ghpull:`24444`: DOC: AnnotationBbox keyword descriptions
* :ghpull:`24468`: Backport PR #24429 on branch v3.6.x (DOC: Clarify transparency in colors)
* :ghpull:`24466`: Backport PR #24460 on branch v3.6.x (Define autoscale() based on autoscale_None().)
* :ghpull:`24460`: Define autoscale() based on autoscale_None().
* :ghpull:`24463`: Backport PR #24459 on branch v3.6.x (removed unused variable and fixed text in doc)
* :ghpull:`24459`: removed unused variable and fixed text in doc
* :ghpull:`24458`: Backport PR #24434 on branch v3.6.x (Fix pyplot.figlegend docstring)
* :ghpull:`24434`: Fix pyplot.figlegend docstring
* :ghpull:`24456`: Backport PR #24402 on branch v3.6.x (DOC: Fix title formats in backend api docs)
* :ghpull:`24438`: Backport PR #24435 on branch v3.6.x (Minor improvements to LogLocator docstring)
* :ghpull:`24435`: Minor improvements to LogLocator docstring
* :ghpull:`24426`: Backport PR #24422 on branch v3.6.x (Make QT_API a link in the qt embedding example.)
* :ghpull:`24411`: Backport PR #24407 on branch v3.6.x (Reword "Reordering is not commutative" phrase in tutorial.)
* :ghpull:`24400`: Backport PR #24399 on branch v3.6.x (Fix docstring of Figure.subfigures.)
* :ghpull:`24399`: Fix docstring of Figure.subfigures.
* :ghpull:`24391`: Backport PR #24380 on branch v3.6.x (DOC: Remove the example "Pythonic Matplotlib")
* :ghpull:`24384`: Backport PR #24377 on branch v3.6.x (DOC: Cleanup Spine placement example)
* :ghpull:`24381`: Backport PR #24366 on branch v3.6.x (DOC: Improve Image Slices Viewer example)
* :ghpull:`24382`: Backport PR #24378 on branch v3.6.x (DOC: Cleanup spines usage in examples)
* :ghpull:`24378`: DOC: Cleanup spines usage in examples
* :ghpull:`24366`: DOC: Improve Image Slices Viewer example
* :ghpull:`24370`: Backport PR #24368 on branch v3.6.x (DOC: Install dev dependencies before building matplotlib)
* :ghpull:`24368`: DOC: Install dev dependencies before building matplotlib
* :ghpull:`24365`: Backport PR #24363 on branch v3.6.x (DOC: Fix syntax of suggestion)
* :ghpull:`24358`: Backport PR #24354 on branch v3.6.x (DOC: clarify rc_context resets all rcParams changes)
* :ghpull:`24354`: DOC: clarify rc_context resets all rcParams changes
* :ghpull:`24353`: Backport PR #24343 on branch v3.6.x (Emit "axes not compatible with tight_layout" in a single place.)
* :ghpull:`24343`: Emit "axes not compatible with tight_layout" in a single place.
* :ghpull:`24346`: Backport PR #24344 on branch v3.6.x (Add test for colorbar extend alpha)
* :ghpull:`24344`: Add test for colorbar extend alpha
* :ghpull:`23974`: Fix repeated word typos

Issues (16):

* :ghissue:`23389`: [Bug]: Colorbar with log scales wrong format
* :ghissue:`24589`: [Bug]: inset_locator is broken when used with subfigures
* :ghissue:`10160`: Low resolution (dpi problem) with Qt5 backend on new iMac Pro Retina
* :ghissue:`24545`: [Bug]: ``matplotlib.pyplot.scatter`` does not respect mask rules with ``datetime``
* :ghissue:`24639`: [Bug]: The Axes3D does not work as expected.
* :ghissue:`22169`: [Doc]: figure.show works beyond what is documented
* :ghissue:`23968`: [Bug]: Zoom rubber band lags in larger window
* :ghissue:`24574`: [Bug]: Extension error (sphinx.ext.linkcode) while building docs
* :ghissue:`24602`: ``close_event`` deprecated warning.
* :ghissue:`24518`: [Doc]: ``layout_engine`` description
* :ghissue:`23581`: [BUG]: frame paths relative to the html file when saving an animation to html
* :ghissue:`23976`: [Doc]: Examples Gallery Layout changed to one or two columns
* :ghissue:`24390`: [Doc]: alpha setting for annotation ``TextArea``
* :ghissue:`24433`: [Doc]: figlegend examples call ``fig.figlegend`` instead of ``plt.figlegend`` or ``fig.legend``
* :ghissue:`24360`: [ENH]: imshow support for multiple slice image volume
* :ghissue:`24359`: [Bug]: Documentation not so clear that a C/C++-compiler is required to install from source
